@@ -108,7 +108,7 @@ class Backend {
         dataArray.push(data)
         resArray.push(res)
         if (finished === languages.length) {
-          if (callback) callback(dataArray, resArray)
+          if (typeof callback === 'function') callback(dataArray, resArray)
         }
       })
     })
