@@ -8,6 +8,10 @@ const server = (done) => {
   js = jsonServer.create()
   js.use(jsonServer.bodyParser)
 
+  js.get('/locales/en/testqs', (req, res) => {
+    res.jsonp(req.query)
+  })
+
   js.get('/locales/en/test', (req, res) => {
     res.jsonp({
       key: 'passing'
@@ -30,6 +34,10 @@ const server = (done) => {
     expect(req.body).not.to.eql({})
     res.jsonp()
   })
+  js.post('/locales/addCustom/en/test', (req, res) => {
+    expect(req.body).not.to.eql({})
+    res.jsonp()
+  })
 
   js.use(jsonServer.defaults())
   js.listen(5001, () => {
